tokenizer\_tools.conll package
==============================

Submodules
----------

tokenizer\_tools.conll.entity\_vocabulary module
------------------------------------------------

.. automodule:: tokenizer_tools.conll.entity_vocabulary
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.conll.iterator\_reader module
----------------------------------------------

.. automodule:: tokenizer_tools.conll.iterator_reader
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.conll.reader module
------------------------------------

.. automodule:: tokenizer_tools.conll.reader
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.conll.tag\_collector module
--------------------------------------------

.. automodule:: tokenizer_tools.conll.tag_collector
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.conll.writer module
------------------------------------

.. automodule:: tokenizer_tools.conll.writer
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tokenizer_tools.conll
   :members:
   :undoc-members:
   :show-inheritance:
